==> avogadro-debuginfo-1.2.0-4.tar.xz: usr/src/debug/avogadro-1.2.0-4/libavogadro/src/tools/qrc_autorotatetool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-4.x86_64/src/avogadro-1.2.0/libavogadro/src/tools/autorotate.png
  0x0,0x0,0x4,0x9e,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x3,0x76,0x0,0x0,0x3,0x76,
  0x1,0x7d,0xd5,0x82,0xcc,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,
  0x70,0x65,0x2e,0x6f,0x72,0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x4,0x1b,0x49,0x44,
  0x41,0x54,0x78,0xda,0xad,0x97,0x5d,0x4c,0x1c,0x65,0x14,0x86,0xdf,0xf3,0xed,0xc2,
  0x2e,0x48,0x4b,0xa5,0x94,0x52,0xbd,0xc0,0x6a,0x94,0xa8,0x17,0xd5,0x9a,0xb6,0x5a,
  0x6a,0x2c,0x37,0xfc,0x54,0xbd,0x30,0x36,0x8d,0x24,0x56,0x28,0x6d,0x29,0x95,0x12,
  0xd3,0xd0,0x1a,0x43,0x8d,0x8a,0x49,0xd1,0x34,0x2a,0xc6,0x6,0x5,0xd2,0x6,0x88,
  0x4d,0x34,0x11,0xfc,0x69,0x95,0x2,0x5e,0xa8,0xa5,0x4d,0x13,0x2b,0x58,0x8c,0x9a,
  0x60,0x63,0xd2,0xc4,0xc4,0x68,0xca,0x85,0x17,0x6,0xd8,0x9d,0xf9,0xbe,0xe3,0x99,
  0x30,0xc8,0x86,0x9d,0x5d,0x87,0x1d,0x9f,0xe4,0xec,0x99,0xdd,0x8b,0xef,0x7d,0xcf,
  0x4f,0x66,0x66,0xc1,0xcc,0x19,0x47,0xeb,0xde,0x8f,0x8a,0x8f,0xee,0xfe,0x60,0x20,
  0xc8,0x19,0xa,0x19,0xf2,0xe2,0xfe,0xc1,0x3a,0x6d,0xeb,0x9f,0xb5,0x6d,0x9e,0x44,
  0x0,0xc2,0x58,0x26,0xaf,0x1e,0xfa,0xac,0xc4,0x8e,0xeb,0x1e,0x11,0xaf,0xb0,0x6d,
  0x3,0xdb,0xd6,0x8,0x2,0x31,0x33,0xfc,0xf0,0x7a,0xcb,0x17,0x24,0xc2,0x4d,0x96,
  0x65,0xbf,0x66,0xc5,0x75,0x9e,0x65,0x69,0x58,0x71,0x1b,0x4e,0x9e,0x99,0x99,0xf9,
  0x8d,0x80,0x1f,0xc1,0xb8,0x6a,0x80,0xc1,0xbe,0x91,0x83,0xe3,0xff,0xab,0x81,0x13,
  0x47,0x86,0x4a,0x45,0xe8,0xb4,0x8,0x96,0x25,0xa,0x8b,0x21,0xc9,0x36,0x62,0xf1,
  0xd8,0xd2,0x43,0x26,0xc1,0xfc,0x52,0xef,0xc8,0xb3,0xe7,0x2,0x19,0xe8,0x68,0x1d,
  0xd,0xdb,0x96,0x3e,0x2a,0x62,0x2f,0x8b,0x50,0x44,0x2a,0x87,0x2d,0x82,0x4e,0xb6,
  0x12,0xb2,0x36,0x36,0xa7,0x3a,0x22,0x7b,0x3a,0xf4,0x42,0xf7,0x77,0xd,0x16,0x52,
  0xa0,0x90,0x6,0xad,0x4d,0xb7,0xcc,0xb8,0x5d,0x22,0xa2,0x2d,0x3,0x99,0x3b,0xe6,
  0xe7,0xbe,0x98,0xb5,0xe4,0x34,0x1c,0x8e,0x17,0xea,0xb1,0x3d,0xd5,0x5d,0xb7,0x65,
  0x64,0x40,0x4,0xe,0x88,0x40,0xab,0x8,0xc7,0xfe,0x15,0xb5,0xe6,0xb3,0x76,0xc4,
  0xfd,0x2d,0xe1,0x66,0x30,0x4f,0xd4,0x57,0xbe,0xbb,0x35,0xe3,0x1d,0x38,0xb6,0x6f,
  0xa0,0x54,0xe6,0x7e,0x5a,0x46,0x51,0x66,0x2f,0x69,0xbf,0xfc,0x86,0x68,0x6e,0xc8,
  0xcf,0x26,0x5f,0x43,0x2c,0x67,0x43,0xef,0x57,0x75,0x73,0x1e,0x1d,0x48,0xcf,0xf1,
  0x53,0x3b,0xa7,0xa4,0xda,0x87,0xa5,0xea,0x66,0xa9,0xf8,0xef,0xf9,0x6e,0x2c,0x76,
  0x82,0xc,0xca,0x41,0x78,0x3,0xc0,0x2f,0x48,0xcd,0x9d,0x1c,0x9d,0x3d,0x96,0xa2,
  0x3,0xfe,0xd9,0xff,0xe8,0xa9,0x12,0x19,0x43,0x8f,0x74,0xa0,0x62,0xa1,0x13,0x1f,
  0x5f,0x39,0x4c,0x10,0xda,0xda,0xda,0xd4,0xf5,0xcb,0x6b,0x5f,0x1,0xd8,0x11,0x22,
  0x24,0x63,0x31,0xcc,0xc6,0xbe,0xe1,0xa6,0x9f,0x52,0x18,0xf0,0xcf,0x53,0xdb,0x4e,
  0xd6,0x89,0x81,0xb7,0xc4,0xc0,0xcd,0x67,0xbf,0x3f,0x42,0x48,0xa0,0xb6,0xb2,0xeb,
  0x31,0x45,0x3c,0x0,0x20,0x1b,0xc9,0x5c,0xee,0x1d,0x3e,0x58,0xb6,0x38,0x82,0xc,
  0xf9,0xf0,0x62,0x73,0x9f,0x8c,0xe5,0x1e,0x19,0xc1,0x20,0x96,0xd0,0x3f,0xd2,0xf8,
  0x39,0x40,0x27,0xe0,0xcd,0x43,0xf5,0x55,0x9d,0x1b,0xe1,0x12,0x46,0x0,0x3e,0x1d,
  0x6f,0xf9,0x43,0xd2,0x4e,0x78,0x11,0x8b,0xb6,0x73,0x64,0xb6,0x86,0x80,0x3b,0xb0,
  0x4,0x66,0x7a,0x5c,0xd2,0x44,0x9a,0xe,0x4,0xc7,0xd9,0x76,0x62,0xf4,0xc0,0xb,
  0xa2,0xed,0x81,0x3b,0x70,0xa0,0xba,0x67,0x9b,0x51,0xea,0x4d,0x8,0xca,0x98,0x96,
  0xee,0xf3,0xd,0x17,0x93,0x2b,0xe5,0x49,0x22,0x82,0x7,0xb7,0x6,0xde,0x1,0x57,
  0x7c,0xb3,0x13,0xee,0x75,0x12,0x59,0xc6,0x9a,0x84,0x37,0xc5,0x3e,0xc,0x4,0x67,
  0x2e,0x9c,0x93,0xf2,0xfc,0x60,0x6,0xdc,0xb6,0x4b,0xfa,0xd6,0x9,0xf7,0x3a,0x9,
  0xc5,0xe6,0x1,0x78,0xf3,0x7b,0xe0,0x1d,0x70,0x67,0xbe,0xe5,0x3f,0xaa,0xf3,0x34,
  0x40,0x62,0xc0,0x77,0x7,0xda,0xca,0xdb,0xc2,0x44,0x20,0x2c,0x93,0x5d,0x5b,0x3b,
  0x72,0x40,0x5c,0x3,0xf,0x98,0xe8,0x42,0x92,0x1,0xf2,0x58,0xd7,0xa7,0x77,0x9c,
  0x5c,0x79,0x3d,0xab,0x78,0x7d,0x6d,0x75,0xcf,0xed,0x58,0x26,0x79,0xf9,0x39,0xc7,
  0x25,0xdd,0x5,0xf,0x88,0xf5,0x59,0xcf,0x5b,0xf1,0xee,0xaa,0xb7,0xd7,0x85,0x43,
  0xd9,0x6c,0x94,0xa,0x91,0xb6,0xa2,0xca,0xa8,0x7c,0x63,0xa8,0x10,0xa,0xc5,0x50,
  0xe1,0x4b,0x7d,0x43,0xd,0xbf,0xc2,0x7,0x7b,0xaa,0x3b,0x77,0x80,0xd5,0x39,0xef,
  0xe7,0x1,0x4d,0xf5,0xe,0x37,0xde,0xed,0xb9,0x3,0xc4,0x51,0x6d,0xb4,0xb9,0x97,
  0x8c,0x56,0xe0,0x70,0x14,0xcc,0x79,0x8a,0xb8,0xc0,0x40,0xad,0x51,0x46,0x3f,0x58,
  0x5f,0xf5,0xde,0x44,0x9e,0xb2,0xdf,0x7f,0x67,0xa8,0x39,0x96,0xaa,0xed,0x4e,0xe5,
  0x22,0xfe,0x9c,0xa7,0xb8,0x60,0x8c,0x6e,0x4d,0xfb,0x34,0xac,0xad,0xe8,0x7c,0x82,
  0x94,0xba,0x85,0x8,0x11,0x30,0xdf,0x4,0xd0,0x2a,0x2,0xa,0x19,0x28,0x2,0xb0,
  0x4e,0x22,0x6,0xa6,0x21,0x3,0x8c,0x1b,0x52,0xe3,0xb,0xdb,0xae,0x20,0x1b,0x4f,
  0x54,0xe3,0xb6,0x3d,0x5,0x34,0x26,0xd5,0x3f,0x92,0xf6,0xb5,0x3c,0x4b,0xc5,0xbf,
  0xd1,0x88,0x3e,0xf,0xa6,0x2,0x10,0xe7,0x2,0x58,0xc9,0x40,0x1,0x18,0x6b,0x0,
  0xac,0x75,0xbe,0x83,0x78,0x93,0x72,0x84,0xa1,0xdd,0x73,0xdd,0x8f,0xf4,0x4c,0x87,
  0x42,0xfa,0x19,0x5f,0xef,0x3,0x7b,0xab,0xba,0x37,0x30,0x4c,0x87,0x21,0x5e,0x41,
  0x4c,0x2b,0x0,0x5e,0xc5,0xa0,0xd5,0x4,0x84,0x90,0x19,0x16,0x48,0x57,0xf6,0x9e,
  0x3f,0xf4,0xb5,0xef,0x17,0x92,0xba,0x8a,0xae,0x32,0x52,0x7c,0x6,0x40,0x9,0x82,
  0x31,0x2d,0xe2,0xbb,0x5c,0x71,0xff,0x77,0xc2,0xbe,0xd1,0xc6,0x4b,0xa1,0x90,0xd9,
  0xee,0xcc,0xd,0x19,0x43,0x63,0x72,0xc6,0xa6,0x44,0x71,0xbf,0x1d,0x48,0x5a,0x4c,
  0xa5,0x42,0xed,0x0,0x97,0xfa,0x14,0x9e,0x72,0xb6,0xbd,0x7f,0xb4,0xe9,0x93,0x8c,
  0xff,0x98,0xb8,0xf7,0xa5,0x88,0x44,0xf6,0x42,0x94,0xdf,0xb7,0xef,0xfe,0xd5,0xf9,
  0xeb,0x2b,0xa3,0x59,0xb9,0x5b,0x88,0x42,0x45,0x8a,0x54,0x11,0x4,0xc3,0xe6,0x6,
  0x1b,0xfb,0xcf,0x59,0x6b,0xe6,0xca,0x8d,0xbf,0xae,0x7d,0x79,0xe1,0x87,0xfe,0xab,
  0x0,0x2c,0x89,0x78,0x42,0xc4,0x44,0xcb,0x9f,0x1,0x11,0x57,0x92,0xc2,0x9,0x6,
  0x22,0x6e,0x44,0x13,0x22,0xc7,0xfd,0x4d,0xb9,0x62,0x31,0x89,0x39,0x89,0x59,0x37,
  0xc7,0x12,0xc3,0x35,0x61,0x2f,0xd5,0xfb,0x7,0xba,0x23,0x98,0xa5,0x93,0xb9,0x14,
  0x0,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // autorotate
  0x0,0xa,
  0x6,0x9b,0xb1,0xc5,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,
    // autorotate.png
  0x0,0xe,
  0x1,0xcd,0x60,0x27,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/autorotate
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/autorotate/autorotate.png
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_autorotatetool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_autorotatetool))

int QT_MANGLE_NAMESPACE(qCleanupResources_autorotatetool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_autorotatetool))

==> avogadro-debuginfo-1.2.0-5.tar.xz: usr/src/debug/avogadro-1.2.0-5/libavogadro/src/tools/qrc_autorotatetool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /wip/cygport-git/avogadro/avogadro-1.2.0-5.x86_64/src/avogadro-1.2.0/libavogadro/src/tools/autorotate.png
  0x0,0x0,0x4,0x9e,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x3,0x76,0x0,0x0,0x3,0x76,
  0x1,0x7d,0xd5,0x82,0xcc,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,
  0x70,0x65,0x2e,0x6f,0x72,0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x4,0x1b,0x49,0x44,
  0x41,0x54,0x78,0xda,0xad,0x97,0x5d,0x4c,0x1c,0x65,0x14,0x86,0xdf,0xf3,0xed,0xc2,
  0x2e,0x48,0x4b,0xa5,0x94,0x52,0xbd,0xc0,0x6a,0x94,0xa8,0x17,0xd5,0x9a,0xb6,0x5a,
  0x6a,0x2c,0x37,0xfc,0x54,0xbd,0x30,0x36,0x8d,0x24,0x56,0x28,0x6d,0x29,0x95,0x12,
  0xd3,0xd0,0x1a,0x43,0x8d,0x8a,0x49,0xd1,0x34,0x2a,0xc6,0x6,0x5,0xd2,0x6,0x88,
  0x4d,0x34,0x11,0xfc,0x69,0x95,0x2,0x5e,0xa8,0xa5,0x4d,0x13,0x2b,0x58,0x8c,0x9a,
  0x60,0x63,0xd2,0xc4,0xc4,0x68,0xca,0x85,0x17,0x6,0xd8,0x9d,0xf9,0xbe,0xe3,0x99,
  0x30,0xc8,0x86,0x9d,0x5d,0x87,0x1d,0x9f,0xe4,0xec,0x99,0xdd,0x8b,0xef,0x7d,0xcf,
  0x4f,0x66,0x66,0xc1,0xcc,0x19,0x47,0xeb,0xde,0x8f,0x8a,0x8f,0xee,0xfe,0x60,0x20,
  0xc8,0x19,0xa,0x19,0xf2,0xe2,0xfe,0xc1,0x3a,0x6d,0xeb,0x9f,0xb5,0x6d,0x9e,0x44,
  0x0,0xc2,0x58,0x26,0xaf,0x1e,0xfa,0xac,0xc4,0x8e,0xeb,0x1e,0x11,0xaf,0xb0,0x6d,
  0x3,0xdb,0xd6,0x8,0x2,0x31,0x33,0xfc,0xf0,0x7a,0xcb,0x17,0x24,0xc2,0x4d,0x96,
  0x65,0xbf,0x66,0xc5,0x75,0x9e,0x65,0x69,0x58,0x71,0x1b,0x4e,0x9e,0x99,0x99,0xf9,
  0x8d,0x80,0x1f,0xc1,0xb8,0x6a,0x80,0xc1,0xbe,0x91,0x83,0xe3,0xff,0xab,0x81,0x13,
  0x47,0x86,0x4a,0x45,0xe8,0xb4,0x8,0x96,0x25,0xa,0x8b,0x21,0xc9,0x36,0x62,0xf1,
  0xd8,0xd2,0x43,0x26,0xc1,0xfc,0x52,0xef,0xc8,0xb3,0xe7,0x2,0x19,0xe8,0x68,0x1d,
  0xd,0xdb,0x96,0x3e,0x2a,0x62,0x2f,0x8b,0x50,0x44,0x2a,0x87,0x2d,0x82,0x4e,0xb6,
  0x12,0xb2,0x36,0x36,0xa7,0x3a,0x22,0x7b,0x3a,0xf4,0x42,0xf7,0x77,0xd,0x16,0x52,
  0xa0,0x90,0x6,0xad,0x4d,0xb7,0xcc,0xb8,0x5d,0x22,0xa2,0x2d,0x3,0x99,0x3b,0xe6,
  0xe7,0xbe,0x98,0xb5,0xe4,0x34,0x1c,0x8e,0x17,0xea,0xb1,0x3d,0xd5,0x5d,0xb7,0x65,
  0x64,0x40,0x4,0xe,0x88,0x40,0xab,0x8,0xc7,0xfe,0x15,0xb5,0xe6,0xb3,0x76,0xc4,
  0xfd,0x2d,0xe1,0x66,0x30,0x4f,0xd4,0x57,0xbe,0xbb,0x35,0xe3,0x1d,0x38,0xb6,0x6f,
  0xa0,0x54,0xe6,0x7e,0x5a,0x46,0x51,0x66,0x2f,0x69,0xbf,0xfc,0x86,0x68,0x6e,0xc8,
  0xcf,0x26,0x5f,0x43,0x2c,0x67,0x43,0xef,0x57,0x75,0x73,0x1e,0x1d,0x48,0xcf,0xf1,
  0x53,0x3b,0xa7,0xa4,0xda,0x87,0xa5,0xea,0x66,0xa9,0xf8,0xef,0xf9,0x6e,0x2c,0x76,
  0x82,0xc,0xca,0x41,0x78,0x3,0xc0,0x2f,0x48,0xcd,0x9d,0x1c,0x9d,0x3d,0x96,0xa2,
  0x3,0xfe,0xd9,0xff,0xe8,0xa9,0x12,0x19,0x43,0x8f,0x74,0xa0,0x62,0xa1,0x13,0x1f,
  0x5f,0x39,0x4c,0x10,0xda,0xda,0xda,0xd4,0xf5,0xcb,0x6b,0x5f,0x1,0xd8,0x11,0x22,
  0x24,0x63,0x31,0xcc,0xc6,0xbe,0xe1,0xa6,0x9f,0x52,0x18,0xf0,0xcf,0x53,0xdb,0x4e,
  0xd6,0x89,0x81,0xb7,0xc4,0xc0,0xcd,0x67,0xbf,0x3f,0x42,0x48,0xa0,0xb6,0xb2,0xeb,
  0x31,0x45,0x3c,0x0,0x20,0x1b,0xc9,0x5c,0xee,0x1d,0x3e,0x58,0xb6,0x38,0x82,0xc,
  0xf9,0xf0,0x62,0x73,0x9f,0x8c,0xe5,0x1e,0x19,0xc1,0x20,0x96,0xd0,0x3f,0xd2,0xf8,
  0x39,0x40,0x27,0xe0,0xcd,0x43,0xf5,0x55,0x9d,0x1b,0xe1,0x12,0x46,0x0,0x3e,0x1d,
  0x6f,0xf9,0x43,0xd2,0x4e,0x78,0x11,0x8b,0xb6,0x73,0x64,0xb6,0x86,0x80,0x3b,0xb0,
  0x4,0x66,0x7a,0x5c,0xd2,0x44,0x9a,0xe,0x4,0xc7,0xd9,0x76,0x62,0xf4,0xc0,0xb,
  0xa2,0xed,0x81,0x3b,0x70,0xa0,0xba,0x67,0x9b,0x51,0xea,0x4d,0x8,0xca,0x98,0x96,
  0xee,0xf3,0xd,0x17,0x93,0x2b,0xe5,0x49,0x22,0x82,0x7,0xb7,0x6,0xde,0x1,0x57,
  0x7c,0xb3,0x13,0xee,0x75,0x12,0x59,0xc6,0x9a,0x84,0x37,0xc5,0x3e,0xc,0x4,0x67,
  0x2e,0x9c,0x93,0xf2,0xfc,0x60,0x6,0xdc,0xb6,0x4b,0xfa,0xd6,0x9,0xf7,0x3a,0x9,
  0xc5,0xe6,0x1,0x78,0xf3,0x7b,0xe0,0x1d,0x70,0x67,0xbe,0xe5,0x3f,0xaa,0xf3,0x34,
  0x40,0x62,0xc0,0x77,0x7,0xda,0xca,0xdb,0xc2,0x44,0x20,0x2c,0x93,0x5d,0x5b,0x3b,
  0x72,0x40,0x5c,0x3,0xf,0x98,0xe8,0x42,0x92,0x1,0xf2,0x58,0xd7,0xa7,0x77,0x9c,
  0x5c,0x79,0x3d,0xab,0x78,0x7d,0x6d,0x75,0xcf,0xed,0x58,0x26,0x79,0xf9,0x39,0xc7,
  0x25,0xdd,0x5,0xf,0x88,0xf5,0x59,0xcf,0x5b,0xf1,0xee,0xaa,0xb7,0xd7,0x85,0x43,
  0xd9,0x6c,0x94,0xa,0x91,0xb6,0xa2,0xca,0xa8,0x7c,0x63,0xa8,0x10,0xa,0xc5,0x50,
  0xe1,0x4b,0x7d,0x43,0xd,0xbf,0xc2,0x7,0x7b,0xaa,0x3b,0x77,0x80,0xd5,0x39,0xef,
  0xe7,0x1,0x4d,0xf5,0xe,0x37,0xde,0xed,0xb9,0x3,0xc4,0x51,0x6d,0xb4,0xb9,0x97,
  0x8c,0x56,0xe0,0x70,0x14,0xcc,0x79,0x8a,0xb8,0xc0,0x40,0xad,0x51,0x46,0x3f,0x58,
  0x5f,0xf5,0xde,0x44,0x9e,0xb2,0xdf,0x7f,0x67,0xa8,0x39,0x96,0xaa,0xed,0x4e,0xe5,
  0x22,0xfe,0x9c,0xa7,0xb8,0x60,0x8c,0x6e,0x4d,0xfb,0x34,0xac,0xad,0xe8,0x7c,0x82,
  0x94,0xba,0x85,0x8,0x11,0x30,0xdf,0x4,0xd0,0x2a,0x2,0xa,0x19,0x28,0x2,0xb0,
  0x4e,0x22,0x6,0xa6,0x21,0x3,0x8c,0x1b,0x52,0xe3,0xb,0xdb,0xae,0x20,0x1b,0x4f,
  0x54,0xe3,0xb6,0x3d,0x5,0x34,0x26,0xd5,0x3f,0x92,0xf6,0xb5,0x3c,0x4b,0xc5,0xbf,
  0xd1,0x88,0x3e,0xf,0xa6,0x2,0x10,0xe7,0x2,0x58,0xc9,0x40,0x1,0x18,0x6b,0x0,
  0xac,0x75,0xbe,0x83,0x78,0x93,0x72,0x84,0xa1,0xdd,0x73,0xdd,0x8f,0xf4,0x4c,0x87,
  0x42,0xfa,0x19,0x5f,0xef,0x3,0x7b,0xab,0xba,0x37,0x30,0x4c,0x87,0x21,0x5e,0x41,
  0x4c,0x2b,0x0,0x5e,0xc5,0xa0,0xd5,0x4,0x84,0x90,0x19,0x16,0x48,0x57,0xf6,0x9e,
  0x3f,0xf4,0xb5,0xef,0x17,0x92,0xba,0x8a,0xae,0x32,0x52,0x7c,0x6,0x40,0x9,0x82,
  0x31,0x2d,0xe2,0xbb,0x5c,0x71,0xff,0x77,0xc2,0xbe,0xd1,0xc6,0x4b,0xa1,0x90,0xd9,
  0xee,0xcc,0xd,0x19,0x43,0x63,0x72,0xc6,0xa6,0x44,0x71,0xbf,0x1d,0x48,0x5a,0x4c,
  0xa5,0x42,0xed,0x0,0x97,0xfa,0x14,0x9e,0x72,0xb6,0xbd,0x7f,0xb4,0xe9,0x93,0x8c,
  0xff,0x98,0xb8,0xf7,0xa5,0x88,0x44,0xf6,0x42,0x94,0xdf,0xb7,0xef,0xfe,0xd5,0xf9,
  0xeb,0x2b,0xa3,0x59,0xb9,0x5b,0x88,0x42,0x45,0x8a,0x54,0x11,0x4,0xc3,0xe6,0x6,
  0x1b,0xfb,0xcf,0x59,0x6b,0xe6,0xca,0x8d,0xbf,0xae,0x7d,0x79,0xe1,0x87,0xfe,0xab,
  0x0,0x2c,0x89,0x78,0x42,0xc4,0x44,0xcb,0x9f,0x1,0x11,0x57,0x92,0xc2,0x9,0x6,
  0x22,0x6e,0x44,0x13,0x22,0xc7,0xfd,0x4d,0xb9,0x62,0x31,0x89,0x39,0x89,0x59,0x37,
  0xc7,0x12,0xc3,0x35,0x61,0x2f,0xd5,0xfb,0x7,0xba,0x23,0x98,0xa5,0x93,0xb9,0x14,
  0x0,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // autorotate
  0x0,0xa,
  0x6,0x9b,0xb1,0xc5,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,
    // autorotate.png
  0x0,0xe,
  0x1,0xcd,0x60,0x27,
  0x0,0x61,
  0x0,0x75,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x6f,0x0,0x74,0x0,0x61,0x0,0x74,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/autorotate
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/autorotate/autorotate.png
  0x0,0x0,0x0,0x1a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_autorotatetool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_autorotatetool))

int QT_MANGLE_NAMESPACE(qCleanupResources_autorotatetool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_autorotatetool))
